-- init.lua
require('coc')
require('keys')
require('look')
require('opts')
require('plug')
require('tele')
require('tree')
require('zen')

-- enable spellcheck
vim.cmd('setlocal spelllang=en_us,tl') -- english(us) and filipino(tagalog)
